@@ -765,7 +765,10 @@ class Client(object):
 
         processor = lambda path, node, exists=exists, directory=directory, zero_length=zero_length: self._handle_test(path, node, exists, directory, zero_length)
         try:
-            return all(self._find_items([path], processor, include_toplevel=True))
+            items = list(self._find_items([path], processor, include_toplevel=True))
+            if len(items) == 0:
+                return False
+            return all(items)
         except FileNotFoundException, e:
             if exists:
                 return False
